@@ -9,28 +9,31 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <ctype.h>
 #include "dicom.h"
 
-char dicom_version[]="libdicom 0.32",**dicom_transfer_syntax=0L;
+#define DICOM_MAX_LENGTH_UI  64 /* as per standard */
+
+char dicom_version[]="libdicom 0.33", **dicom_transfer_syntax=0L, dicom_transfer_syntax_str[DICOM_MAX_LENGTH_UI+1];
 
 WORKAROUND dicom_workaround;
 
-static void	dicom_transfer(void);
-static void	dicom_vr(void);
-static void	dicom_encapsulated(int);
-static void	dicom_sequence(int);
-static void	dicom_endian(void);
-static int	dicom_vm(void);
+static void dicom_transfer(void);
+static void dicom_vr(void);
+static void dicom_encapsulated(int);
+static void dicom_sequence(int);
+static void dicom_endian(void);
+static int  dicom_vm(void);
 
 #if MDC_DICOM_DEBUG
 static void     mdc_dicom_debug_tag(void);
 #endif
-static void	mdc_dicom_endian(void);
-	
-static ELEMENT	element;
-static FILE	*stream=0L;
-static long	position;
-static int	meta;
+static void mdc_dicom_endian(void);
+
+static ELEMENT element;
+static FILE *stream=0L;
+static off_t position;
+static int meta;
 static enum
 {
   LITTLE=1,
@@ -40,7 +43,8 @@ static enum
   COMPRESSED_UNKNOWN=16,
   COMPRESSED_LOSSLESS = 32,
   COMPRESSED_LOSSLY = 64,
-  COMPRESSED_RLE = 128
+  COMPRESSED_RLE = 128,
+  UNCOMPRESSED_EXPLICIT_LITTLE = 256
 }
 syntax,endian,filesyntax,pixelsyntax,encapsyntax;
 
@@ -64,13 +68,13 @@ void dicom_init(FILE *fp)
 
 int dicom_open(const char *file)
 {
-  U16	magic=0x1234;
+  U16 magic=0x1234;
   char  vr[2];
-  int	r;
+  size_t r;
 #if MEDCON_INTEGRATED
   char  buffer[512];
 #else
-  char	*dot,*tmp,buffer[512];
+  char *dot,*tmp,buffer[512];
 #endif 
 
   dicom_log(DEBUG,"dicom_open()");
@@ -124,7 +128,7 @@ int dicom_open(const char *file)
 #endif
 
   r = fread(buffer,1,132,stream);
-  if (r != 132) {
+  if (r != (size_t)132) {
     if (dicom_check(0)) return -5;
   }
 
@@ -139,25 +143,29 @@ int dicom_open(const char *file)
 
     /* watch out for LITTLE|IMPLICIT */
     r = fread(&element.group,2,2,stream);
-    if (r != 2) {
+    if (r != (size_t)2) {
       if (dicom_check(0)) return -6;
     }
     dicom_swap(&element.group,2);
     dicom_swap(&element.element,2);
     r = fread(vr,1,2,stream);
-    if (r != 2) {
+    if (r != (size_t)2) {
       if (dicom_check(0)) return -7;
     }
+    /* eNlf: make sure it is uppercase */
+    vr[0]=(char)toupper(vr[0]);
+    vr[1]=(char)toupper(vr[1]);
+
     element.vr=(*vr<<8)|vr[1];
 
     if (element.vr != UL) syntax=LITTLE|IMPLICIT;  /* weird */
 
-    fseek(stream,132,SEEK_SET);
+    fseeko(stream,(off_t)132,SEEK_SET);
 
   }
   else
   {
-    rewind(stream);
+    fseeko(stream,(off_t)0,SEEK_SET);
 
     meta=0;
 
@@ -195,20 +203,20 @@ int dicom_open(const char *file)
 
 ELEMENT *dicom_element(void)
 {
-  long	rewind;
-  U16	tmp;
-  char	vr[2];
-  int	r;
+  off_t rewind;
+  U16 tmp;
+  char vr[2];
+  size_t r;
 
   dicom_log(DEBUG,"dicom_element()");
 
   if (!stream)
     return 0L;
 
-  position=ftell(stream);
+  position=ftello(stream);
 
   r = fread(&element.group,2,2,stream);
-  if (r != 2) {
+  if (r != (size_t)2) {
     if (dicom_check(-1)) return 0L;
   }
   dicom_swap(&element.group,2);
@@ -238,7 +246,7 @@ ELEMENT *dicom_element(void)
       meta=0;
       dicom_transfer();
 
-      fseek(stream,position,SEEK_SET);  
+      fseeko(stream,position,SEEK_SET);
       return dicom_element();
     }
 
@@ -255,9 +263,13 @@ ELEMENT *dicom_element(void)
   else
   {
     r = fread(vr,1,2,stream);
-    if (r != 2) {
+    if (r != (size_t)2) {
       if (dicom_check(-1)) return 0L;
     }
+    /* eNlf: make sure it is uppercase */
+    vr[0]=(char)toupper(vr[0]);
+    vr[1]=(char)toupper(vr[1]);
+
     element.vr=(*vr<<8)|vr[1];
 
     switch(element.vr)
@@ -267,10 +279,10 @@ ELEMENT *dicom_element(void)
     case SQ :
     case UN :
     case UT :
-      fseek(stream,2,SEEK_CUR);
+      fseeko(stream,(off_t)2,SEEK_CUR);
 
       r = fread(&element.length,4,1,stream);
-      if (r != 1) {
+      if (r != (size_t)1) {
         if (dicom_check(-1)) return 0L;
       }
       dicom_swap(&element.length,4);
@@ -278,7 +290,7 @@ ELEMENT *dicom_element(void)
 
     default :
       r = fread(&tmp,2,1,stream);
-      if (r != 1) {
+      if (r != (size_t)1) {
         if (dicom_check(-1)) return 0L;
       }
       dicom_swap(&tmp,2);
@@ -309,11 +321,21 @@ ELEMENT *dicom_element(void)
   if (element.group==0x0002)
     if (element.element==0x0010)
     {
-      rewind=ftell(stream);
+      rewind=ftello(stream);
       if (dicom_load(UI))
         return 0L;
-      fseek(stream,rewind,SEEK_SET);
+      fseeko(stream,rewind,SEEK_SET);
       dicom_transfer_syntax=element.value.UI;
+
+      /* eNlf: make a string safe copy */
+      if (element.length == 0 || element.length > DICOM_MAX_LENGTH_UI) {
+        dicom_log(WARNING,"Unallowed length for transfer syntax UI");
+        dicom_transfer_syntax_str[0]='\0'; /* make empty string */
+        dicom_transfer_syntax=0L;
+      }else{ 
+        memcpy(dicom_transfer_syntax_str,*dicom_transfer_syntax,element.length);
+        dicom_transfer_syntax_str[element.length]='\0'; /* last null-terminated */
+      }
     }
 
   return &element;
@@ -340,7 +362,7 @@ int dicom_skip(void)
     if (!element.encapsulated)
       return 0;
 
-  fseek(stream,(long)element.length,SEEK_CUR);
+  fseeko(stream,(off_t)element.length,SEEK_CUR);
 
   return dicom_check(0);
 }
@@ -361,23 +383,23 @@ int mdc_dicom_skip_sequence(ELEMENT *e)
   return(answer);
 }
 
-/*************
- * MDC fseek *
- *************/
+/**************
+ * MDC fseeko *
+ **************/
 
-int mdc_dicom_fseek(U32 offset, int whence)
+int mdc_dicom_fseeko(off_t offset, int whence)
 {
-  fseek(stream,(long)offset,whence);
+  fseeko(stream,offset,whence);
 
   return(dicom_check(0));
 }
 
-/*************
- * MDC ftell *
- *************/
-U32 mdc_dicom_ftell(void)
+/**************
+ * MDC ftello *
+ **************/
+off_t mdc_dicom_ftello(void)
 {
-  return(ftell(stream));
+  return(ftello(stream));
 }
 
 /********
@@ -386,7 +408,7 @@ U32 mdc_dicom_ftell(void)
 
 int dicom_load(VR vr)
 {
-  int r;
+  size_t r;
   dicom_log(DEBUG,"dicom_load()");
 
   if (!stream)
@@ -429,9 +451,9 @@ int dicom_load(VR vr)
       dicom_close();
       return -2;
     }
-    memset(element.value.UN,0,element.length + 4);
-    r = fread(element.value.UN,1,element.length,stream);
-    if (r != element.length) {
+    memset(element.value.UN,'\0',element.length + 4);
+    r = fread(element.value.UN,1,(size_t)element.length,stream);
+    if (r != (size_t)element.length) {
       eNlfSafeFree(element.value.UN);
       if (dicom_check(0)) return -3;
     }
@@ -449,8 +471,8 @@ int dicom_load(VR vr)
  *****************/
 void mdc_dicom_debug_tag(void)
 {
-  fprintf(stdout,"##### TAG DEBUG %12u: (%.4X,%.4X) %c%c[%u] (%u bytes)\n"
-                ,position
+  fprintf(stdout,"##### TAG DEBUG %12jd: (%.4X,%.4X) %c%c[%u] (%u bytes)\n"
+                ,(intmax_t)position
                 ,element.group,element.element
                 ,element.vr>>8,element.vr&0xFF,element.vm
                 ,element.length);
@@ -494,7 +516,7 @@ void mdc_dicom_switch_syntax_endian(void)
    routine and get the header info we need */
 int mdc_dicom_load(VR vr)
 {
-  int	r;
+  size_t r;
   dicom_log(DEBUG,"dicom_load()");
 
   if (!stream)
@@ -532,9 +554,9 @@ int mdc_dicom_load(VR vr)
       dicom_close();
       return -2;
     }
-    memset(element.value.UN,0,element.length + 4);
-    r = fread(element.value.UN,1,element.length,stream);
-    if (r != element.length) {
+    memset(element.value.UN,'\0',element.length + 4);
+    r = fread(element.value.UN,1,(size_t)element.length,stream);
+    if (r != (size_t)element.length) {
       eNlfSafeFree(element.value.UN);
       if (dicom_check(0)) return -3;
     }
@@ -553,8 +575,8 @@ int mdc_dicom_load(VR vr)
 
 void dicom_clean(void)
 {
-  U32	i;
-  char	*c;
+  U32 i;
+  char *c;
 
   dicom_log(DEBUG,"dicom_clean()");
 
@@ -565,7 +587,7 @@ void dicom_clean(void)
       for (c=element.value.PN[i]; *c; c++)
         if (*c=='^')
           *c=' ';
-
+    /* no break; fall through on purpose */
   case AE :
   case AS :
   case CS :
@@ -627,7 +649,7 @@ int dicom_close(void)
   stream=0L;
 
 #else
-  fseek(stream,0,SEEK_SET);
+  fseeko(stream,(off_t)0,SEEK_SET);
 #endif
 
 
@@ -648,61 +670,61 @@ static void dicom_transfer(void)
     return;
   }
 
-  if (strncmp(*dicom_transfer_syntax,"1.2.840.113619.5.2",18) == 0)
+  if (strncmp(dicom_transfer_syntax_str,"1.2.840.113619.5.2",18) == 0)
   {
     syntax=LITTLE|IMPLICIT;
     filesyntax=syntax; pixelsyntax=BIG|IMPLICIT;
     return;
   }
-  if (strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2",17))
+  if (strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2",17))
   {
     dicom_log(WARNING,"Transfer syntax is not DICOM");
     return;
   }
 
   encapsyntax = 0;
-  if (!strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4",19))  /* JPEG */
+  if (!strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4",19))  /* JPEG */
   {
-    if (!strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.50",22) ||
+    if (!strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.50",22) ||
         /* baseline */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.51",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.51",22) ||
         /* extended */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.52",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.52",22) ||
         /* extended */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.53",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.53",22) ||
         /* spectral selection, non-hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.54",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.54",22) ||
         /* spectral selection, non-hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.55",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.55",22) ||
         /* full progression, non-hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.56",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.56",22) ||
         /* full progression, non-hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.59",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.59",22) ||
         /* extended, hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.60",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.60",22) ||
         /* extended, hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.61",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.61",22) ||
         /* spectral selection, hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.62",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.62",22) ||
         /* spectral selection, hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.63",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.63",22) ||
         /* full progression, hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.64",22) )
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.64",22) )
         /* full progression, hierarchical */
     {
       encapsyntax = COMPRESSED_LOSSLY;
       return;
     }
     else
-    if (!strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.57",22) ||
+    if (!strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.57",22) ||
         /* lossless, non-hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.58",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.58",22) ||
         /* lossless, non-hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.65",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.65",22) ||
         /* lossless, hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.66",22) ||
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.66",22) ||
         /* lossless, hierarchical */
-        !strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.4.70",22) )
+        !strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.4.70",22) )
         /* lossless, hierarchical,, first order prediction */
     {
       encapsyntax = COMPRESSED_LOSSLESS;
@@ -715,18 +737,25 @@ static void dicom_transfer(void)
     }
   }
 
-  if (!strncmp(*dicom_transfer_syntax,"1.2.840.10008.1.2.5",19))  /* RLE */
+  if (!strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.5",19))  /* RLE */
   {
     encapsyntax = COMPRESSED_RLE;
     return;
   }
 
+  if (!strncmp(dicom_transfer_syntax_str,"1.2.840.10008.1.2.1.98",22))
+  {
+    encapsyntax = UNCOMPRESSED_EXPLICIT_LITTLE;
+    syntax=LITTLE|EXPLICIT;
+    filesyntax=syntax; pixelsyntax=syntax;
+    return;
+  }
 
-  if ((*dicom_transfer_syntax)[17]!='.') {
+  if ((dicom_transfer_syntax_str)[17]!='.') {
     syntax=LITTLE|IMPLICIT;
     filesyntax=syntax; pixelsyntax=syntax;
   }else{
-    switch((*dicom_transfer_syntax)[18])
+    switch((dicom_transfer_syntax_str)[18])
     {
     case '1' :
     case '4' :
@@ -737,7 +766,7 @@ static void dicom_transfer(void)
       break;
     default :
       dicom_log(WARNING,"Unknown transfer syntax");
-      dicom_log(WARNING,*dicom_transfer_syntax);
+      dicom_log(WARNING,dicom_transfer_syntax_str);
     }
   }
 }
@@ -792,8 +821,8 @@ static void dicom_encapsulated(int reset)
 
 static void dicom_sequence(int reset)
 {
-  static U32	length[0x100];
-  static U8	sequence;
+  static U32 length[0x100];
+  static U8 sequence;
   static TAG    sqtag[0x100];
 
   dicom_log(DEBUG,"dicom_sequence()");
@@ -816,13 +845,13 @@ static void dicom_sequence(int reset)
       /* skip those nasty item tags */
       dicom_log(WARNING,"Skip PHILIPS premature item bug");
       element.length=0; element.vm=0;
-      fseek(stream,4,SEEK_CUR);
+      fseeko(stream,(off_t)4,SEEK_CUR);
       return;
     }
 
     if (length[sequence]!=0xFFFFFFFF)
     {
-      *length=ftell(stream)-position;
+      *length=(U32)(ftello(stream)-position);
       if (element.length!=0xFFFFFFFF)
         if (element.group!=0xFFFE || element.element!=0xE000)
           *length+=element.length;
@@ -869,8 +898,8 @@ static void dicom_sequence(int reset)
 
 static void dicom_endian(void)
 {
-  U32	i;
-  U8	*s;
+  U32 i;
+  U8 *s;
 
   dicom_log(DEBUG,"dicom_endian()");
 
@@ -884,7 +913,7 @@ static void dicom_endian(void)
   case SS :
   case US :
     s=element.value.UN;
-    for (i=element.length>>1; i; i--,s+=2)
+    for (i=element.length>>1; i>0; i--,s+=2)
       dicom_swap(s,2);
     return;
 
@@ -892,13 +921,13 @@ static void dicom_endian(void)
   case UL :
   case FL :
     s=element.value.UN;
-    for (i=element.length>>2; i; i--,s+=4)
+    for (i=element.length>>2; i>0; i--,s+=4)
       dicom_swap(s,4);
     return;
 
   case FD :
     s=element.value.UN;
-    for (i=element.length>>3; i; i--,s+=8)
+    for (i=element.length>>3; i>0; i--,s+=8)
       dicom_swap(s,8);
     return;
 
@@ -913,8 +942,8 @@ static void dicom_endian(void)
 
 static int dicom_vm(void)
 {
-  U32	i;
-  char	*c,**table,*s,*d;
+  U32 i;
+  char *c,**table,*s,*d;
 
   dicom_log(DEBUG,"dicom_vm()");
 
@@ -971,7 +1000,7 @@ static int dicom_vm(void)
     case UI :
       element.vm=1;
       c=element.value.UN;
-      for (i=element.length; i; i--,c++)
+      for (i=element.length; i>0; i--,c++)
         if (*c=='\\')
           element.vm++;
 
@@ -979,22 +1008,22 @@ static int dicom_vm(void)
       +element.length+1);
       if (!element.value.UN)
       {
-	dicom_log(ERROR,"Out of memory");
-	dicom_close();
-	return -1;
+        dicom_log(ERROR,"Out of memory");
+        dicom_close();
+        return -1;
       }
 
       c=element.value.LT+element.vm*sizeof(char*);
 
       s=element.value.LT+element.length;
       d=c+element.length;
-      for (i=element.length; i; i--)
+      for (i=element.length; i>0; i--)
         *--d=*--s;
 
       table=element.value.AE;
       *table++=c;
 
-      for (i=element.length; i; i--,c++)
+      for (i=element.length; i>0; i--,c++)
         if (*c=='\\')
         {
           *c=0;
@@ -1026,7 +1055,7 @@ void dicom_swap(void *v,int n)
   b=v;
   e=b+n-1;
 
-  for (i=n>>1; i; i--)
+  for (i=n>>1; i>0; i--)
   {
     tmp=*b;
     *b++=*e;
@@ -1067,7 +1096,7 @@ int mdc_dicom_decompress(SINGLE *s, ELEMENT *e)
   switch (encapsyntax) 
   {
     case COMPRESSED_RLE     :
-        if (mdc_dicom_decomp_rle (stream,(U16*)e->value.OB,e->length))
+        if (mdc_dicom_decomp_rle(stream, s, e))
           return(-1);
         break;
     case COMPRESSED_LOSSLESS:
@@ -1076,14 +1105,17 @@ int mdc_dicom_decompress(SINGLE *s, ELEMENT *e)
           dicom_log(WARNING,"Check out 'jpegutil.c' file to increase");
           return(-2);
         }
-        if (mdc_dicom_decomp_ljpg(stream,(U16*)e->value.OB,e->length
-                                        ,(unsigned)s->alloc*s->samples))
-          return(-2);
+        if (mdc_dicom_decomp_ljpg(stream, s, e))
+          return(-3);
+        break;
+    case UNCOMPRESSED_EXPLICIT_LITTLE:
+        if (mdc_dicom_decomp_uncomp_little(stream, s, e))
+          return(-4);
         break;
     case COMPRESSED_LOSSLY  :
     default:
         /* no valid decompressor */
-          return(-3);
+          return(-5);
   }
 
   return(0);
