@@ -12,7 +12,7 @@
 #include <string.h>
 #include "jpeg.h"
 #include "mcu.h"
-#include "io.h"
+#include "inout.h"
 #include "proto.h"
 #include "predict.h"
 
