@@ -15,7 +15,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -338,7 +338,7 @@ void MdcPrintFI(FILEINFO *fi)
      MdcPrntScrn("rescaled_slope     : %+e\n",id->rescaled_slope);
      MdcPrntScrn("rescaled_intercept : %+e\n",id->rescaled_intercept);
      MdcPrntScrn("buf                : %p\n",id->buf);
-     MdcPrntScrn("load_location      : %ld\n",id->load_location);
+     MdcPrntScrn("load_location      : %jd\n",(intmax_t)id->load_location);
      MdcPrntScrn("quant_units        : %hd\n",id->quant_units);
      MdcPrntScrn("calibr_units       : %hd\n",id->calibr_units);
      MdcPrntScrn("quant_scale        : %+e\n",id->quant_scale);
