@@ -22,7 +22,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -84,7 +84,7 @@ static Uint32 MdcDicomMakeUID(FILEINFO *fi, Int8 uid, char str[]);
 static void MdcDicomWriteInfoSeq(FILE *fp, Uint16 group, Uint16 element);
 static void MdcDicomWriteItem(FILE *fp);
 static void MdcDicomWriteItemDelItem(FILE *fp);
-static void MdcDicomWriteInfoSeqDelItem(FILE *fp);
+static void MdcDicomWriteSeqDelItem(FILE *fp);
 
 static char *MdcDicomWriteMetaHeader (FILEINFO *fi, MDC_DICOM_STUFF_T *dicom);
 static char *MdcDicomWriteSetModality(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom);
@@ -97,7 +97,7 @@ static char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom);
 static char *MdcDicomWriteG7FE0(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom);
 
 /* including the addapted dicom lib functions */
-static int  mdc_dicom_read(FILEINFO *fi, IMAGE **image, int *number);
+static int  mdc_dicom_read(FILEINFO *fi, IMAGE **image, Uint32 *number);
 static void mdc_dicom_dumpinfo(FILEINFO *fi);
 static void mdc_dicom_printinfo(const ELEMENT *e,const char *description);
 static void mdc_dicom_getinfo(FILEINFO *fi);
@@ -108,8 +108,8 @@ static int  mdc_dicom_write_element(FILE *fp, Uint16 group, Uint16 element, Uint
 
 static int MDC_DICOM_VERBOSE = MDC_YES;
 
-static Uint32 MDC_REWRF_SLOPE;         /* rewrite offset to slope     tag */
-static Uint32 MDC_REWRF_INTERCEPT;     /* rewrite offset to intercept tag */
+static off_t MDC_REWRF_SLOPE;         /* rewrite offset to slope     tag */
+static off_t MDC_REWRF_INTERCEPT;     /* rewrite offset to intercept tag */
 
 static Int32 mdc_prev_nr_series = -MDC_TYPE_UID_SERIES;
 static Int32 mdc_prev_series_uid = 0;
@@ -132,9 +132,9 @@ int MdcCheckDICM(FILEINFO *fi)
 {
    char sig[5];
 
-   fseek(fi->ifp,128,SEEK_SET);
+   fseeko(fi->ifp,(off_t)128,SEEK_SET);
    if (fread(sig,1,4,fi->ifp) != 4) return(MDC_BAD_READ);
-   fseek(fi->ifp,0,SEEK_SET);
+   fseeko(fi->ifp,(off_t)0,SEEK_SET);
 
    sig[4]='\0';
    MdcLowStr(sig);
@@ -177,6 +177,7 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
   IMAGE *pimg;
   IMG_DATA *id;
   Uint32 img=0, i, f, bytes, t;
+  Int64 length; /* for large files > 4GB */
   Uint8 *pdata = NULL;
 
   for (img=0, i=0; i<number; i++) {
@@ -206,7 +207,13 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
         }else{
           pdata = (Uint8 *)pimg->data.gray;
         }
-        pdata+=f*bytes;
+
+        /* move data pointer & copy ; cast to Int64 for large file > 4GB     */
+        /* we settle on Int64 because core library uses decreasing for-loops */
+        length = (Int64)bytes * f;
+
+        pdata+=length;
+
         memcpy(id->buf,pdata,bytes);
 
         if (!((img == 0) && (f == 0))) {
@@ -480,9 +487,9 @@ const char *MdcReadDICM(FILEINFO *fi)
   if (MDC_BLOCK_MESSAGES == MDC_NO) dicom_log_level = NOTICE;
 
   /* reading file 2nd time for images */
-  if (mdc_dicom_read(fi,&image,(Int32 *)&nrimages)) {
+  if (mdc_dicom_read(fi,&image,&nrimages)) {
     MdcSplitPath(fi->ipath,fi->idir,fi->ifname);
-    dicom_free(image,(signed)nrimages);
+    dicom_free(image, nrimages);
     return("DICM Error reading file");
   }
 
@@ -495,7 +502,7 @@ const char *MdcReadDICM(FILEINFO *fi)
      pimg = &image[i];
      number += pimg->frames;
      if (number  == 0 ) {
-       dicom_free(image,(signed)nrimages);
+       dicom_free(image, nrimages);
        return("DICM Bad number of images");
      }
      if (pimg->rgb) COLOR = MDC_YES; /* MARK: all images must be identical */
@@ -503,7 +510,7 @@ const char *MdcReadDICM(FILEINFO *fi)
 
 
   if (!MdcGetStructID(fi,number)) {
-    dicom_free(image,(signed)nrimages);
+    dicom_free(image, nrimages);
     return("DICM Bad malloc IMG_DATA structs");
   }
 
@@ -544,7 +551,7 @@ const char *MdcReadDICM(FILEINFO *fi)
   /* in case of mosaic, fake a multi frame image */
   if (MdcCheckMosaic(fi,dicom) == MDC_YES) {
     msg = MdcHandleMosaic(fi,dicom,image);
-    if (msg != NULL) { dicom_free(image,(signed)nrimages); return(msg); }
+    if (msg != NULL) { dicom_free(image, nrimages); return(msg); }
   }
 
   /* fill in the FILEINFO structs */
@@ -575,7 +582,7 @@ const char *MdcReadDICM(FILEINFO *fi)
         }
       }else{
         if (!MdcGetStructDD(fi,1)) {
-          dicom_free(image,(signed)nrimages);
+          dicom_free(image, nrimages);
           return("DICM Couldn't malloc DYNAMIC_DATA structs");
         }
         fi->dyndata[0].nr_of_slices = fi->number;
@@ -605,9 +612,9 @@ const char *MdcReadDICM(FILEINFO *fi)
 
   /* put images and info in IMG_DATA structs */
   msg = MdcDicomHandleImages(fi,dicom,image,nrimages);
-  if (msg != NULL) { dicom_free(image,(signed)nrimages); return(msg); }
+  if (msg != NULL) { dicom_free(image, nrimages); return(msg); }
 
-  dicom_free(image,(signed)nrimages);
+  dicom_free(image, nrimages);
 
   MdcCloseFile(fi->ifp);
 
@@ -711,7 +718,7 @@ void MdcDicomWriteItemDelItem(FILE *fp)
 {
   mdc_dicom_write_element(fp,0xfffe,0xe00d,0,NULL);
 }
-void MdcDicomWriteInfoSeqDelItem(FILE *fp)
+void MdcDicomWriteSeqDelItem(FILE *fp)
 {
   mdc_dicom_write_element(fp,0xfffe,0xe0dd,0,NULL);
 }
@@ -719,7 +726,8 @@ void MdcDicomWriteInfoSeqDelItem(FILE *fp)
 
 char *MdcDicomWriteMetaHeader(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 {
-  Uint32 REWRF, BEGIN, END, len;
+  Uint32 len;
+  off_t REWRF, BEGIN, END;
   Int32 i32;
   FILE *ofp = fi->ofp;
 
@@ -730,10 +738,10 @@ char *MdcDicomWriteMetaHeader(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   strcpy(mdcbufr,"DICM"); fwrite(mdcbufr,1,4,ofp);
 
   /* group 0x0002 */
-  REWRF = ftell(ofp); i32=0;
+  REWRF = ftello(ofp); i32=0;
   mdc_dicom_write_element(ofp,0x0002,0x0000,4,(Uint8 *)&i32);
 
-  BEGIN = ftell(ofp);
+  BEGIN = ftello(ofp);
 
   mdcbufr[0]=0x00; mdcbufr[1]=0x01;
   mdc_dicom_write_element(ofp,0x0002,0x0001,2,(Uint8 *)mdcbufr);
@@ -753,7 +761,9 @@ char *MdcDicomWriteMetaHeader(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   mdc_dicom_write_element(ofp,0x0002,0x0003,len,(Uint8 *)mdcbufr);
 
   /* transfer syntax */
-  if (MDC_DICOM_WRITE_IMPLICIT == MDC_YES) {
+  if (dicom->ENCAPSULATED_UNCOMPRESSED == MDC_YES) {
+    strcpy(mdcbufr,"1.2.840.10008.1.2.1.98");  /* encapsulated uncompressed explicit VR little endian */
+  }else if (MDC_DICOM_WRITE_IMPLICIT == MDC_YES) {
     strcpy(mdcbufr,"1.2.840.10008.1.2");       /* implicit VR little */
   }else{
     if (MDC_FILE_ENDIAN == MDC_LITTLE_ENDIAN) {
@@ -774,12 +784,12 @@ char *MdcDicomWriteMetaHeader(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   strcpy(mdcbufr,"NOTSPECIFIED"); len = strlen(mdcbufr);
   mdc_dicom_write_element(ofp,0x0002,0x0016,len,(Uint8 *)mdcbufr);
 
-  END = ftell(ofp);
+  END = ftello(ofp);
 
   /* rewrite group length */
-  fseek(ofp,(signed)REWRF,SEEK_SET); i32 = END - BEGIN;
+  fseeko(ofp,REWRF,SEEK_SET); i32 = (Int32)(END - BEGIN);
   mdc_dicom_write_element(ofp,0x0002,0x0000,4,(Uint8 *)&i32);
-  fseek(ofp,0,SEEK_END);
+  fseeko(ofp,(off_t)0,SEEK_END);
 
   if (ferror(ofp)) return("DICM Failure to write MetaHeader");
 
@@ -1350,12 +1360,12 @@ char *MdcDicomWriteG0028(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   mdc_dicom_write_element(fi->ofp,0x0028,0x0103,len,(Uint8 *)&ui16);
 
   /* need to rewrite the following tag after rescaling images */
-  MDC_REWRF_INTERCEPT = ftell(fi->ofp);
+  MDC_REWRF_INTERCEPT = ftello(fi->ofp);
   sprintf(mdcbufr,"%+e",intercept); len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0028,0x1052,len,(Uint8 *)mdcbufr);
 
   /* need to rewrite the following tag after rescaling images */
-  MDC_REWRF_SLOPE = ftell(fi->ofp);
+  MDC_REWRF_SLOPE = ftello(fi->ofp);
   sprintf(mdcbufr,"%+e",slope); len = strlen(mdcbufr);
   mdc_dicom_write_element(fi->ofp,0x0028,0x1053,len,(Uint8 *)mdcbufr);
 
@@ -1419,11 +1429,11 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
      /* item delimitation item */
      MdcDicomWriteItemDelItem(fi->ofp);
      /* sequence delimitation item*/
-    MdcDicomWriteInfoSeqDelItem(fi->ofp);
+    MdcDicomWriteSeqDelItem(fi->ofp);
   /* item delimitation item */
   MdcDicomWriteItemDelItem(fi->ofp);
   /* sequence delimitation item */
-  MdcDicomWriteInfoSeqDelItem(fi->ofp);
+  MdcDicomWriteSeqDelItem(fi->ofp);
 
   /* radiopharmaceutical info sequence */
   MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0016);
@@ -1458,7 +1468,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
       /* item delimitation item */
       MdcDicomWriteItemDelItem(fi->ofp);
      /* sequence delimiter */
-     MdcDicomWriteInfoSeqDelItem(fi->ofp);
+     MdcDicomWriteSeqDelItem(fi->ofp);
 
      MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0304);
       /* item */
@@ -1474,7 +1484,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
       /* item delimitation item */
       MdcDicomWriteItemDelItem(fi->ofp);
      /* sequence delimiter */
-     MdcDicomWriteInfoSeqDelItem(fi->ofp);
+     MdcDicomWriteSeqDelItem(fi->ofp);
 
 
 
@@ -1483,7 +1493,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
     /* item delimitation item */
     MdcDicomWriteItemDelItem(fi->ofp);
   /* sequence delimiter */
-  MdcDicomWriteInfoSeqDelItem(fi->ofp);
+  MdcDicomWriteSeqDelItem(fi->ofp);
 
 
   if (dicom->VectDO[MDC_VECT_DETECTOR] == MDC_YES) {
@@ -1561,7 +1571,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
        MdcDicomWriteItemDelItem(fi->ofp);
 
       /* sequence delimitation item */
-      MdcDicomWriteInfoSeqDelItem(fi->ofp);
+      MdcDicomWriteSeqDelItem(fi->ofp);
     }else{
       /* start angle */
       v = acqdata[0].angle_start; v = MdcRotateAngle(v,180.);
@@ -1573,7 +1583,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
    MdcDicomWriteItemDelItem(fi->ofp);
 
   /* sequence delimitation item */
-  MdcDicomWriteInfoSeqDelItem(fi->ofp);
+  MdcDicomWriteSeqDelItem(fi->ofp);
 
   if (dicom->modality == M_PT) {
 
@@ -1653,12 +1663,12 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
     /* patient orientation code sequence */
     MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0410);
     /* sequence delimitation item */
-    MdcDicomWriteInfoSeqDelItem(fi->ofp);
+    MdcDicomWriteSeqDelItem(fi->ofp);
 
     /* patient gantry relationship code sequence */
     MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0414);
     /* sequence delimitation item */
-    MdcDicomWriteInfoSeqDelItem(fi->ofp);
+    MdcDicomWriteSeqDelItem(fi->ofp);
 
     if (fi->reconstructed == MDC_YES)
       strcat(mdcbufr,"\\IMAGE");
@@ -1725,7 +1735,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
          MdcDicomWriteItemDelItem(fi->ofp);
       }
 
-      MdcDicomWriteInfoSeqDelItem(fi->ofp);
+      MdcDicomWriteSeqDelItem(fi->ofp);
 
     }
 
@@ -1815,7 +1825,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
       }
 
       /* sequence delimitation item */
-      MdcDicomWriteInfoSeqDelItem(fi->ofp);
+      MdcDicomWriteSeqDelItem(fi->ofp);
 
     }
 
@@ -1840,7 +1850,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
                                                    ,(Uint8 *)&ui16);
 
       MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0062);
-      for (i=0; i<fi->dim[5]; i++) {
+      for (i=0; i<(Uint32)fi->dim[5]; i++) {
          MdcDicomWriteItem(fi->ofp);
           MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0063);
            MdcDicomWriteItem(fi->ofp);
@@ -1865,7 +1875,7 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
            mdc_dicom_write_element(fi->ofp,0x0018,0x1084,len,(Uint8 *)mdcbufr);
 
             MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0072);
-            for (t=0; t<fi->dim[4]; t++) {
+            for (t=0; t<(Uint32)fi->dim[4]; t++) {
                MdcDicomWriteItem(fi->ofp);
                v = (gd->cycles_acquired * gd->image_duration)/(float)fi->number;
                sprintf(mdcbufr,"%+e",v); len = strlen(mdcbufr);
@@ -1873,14 +1883,14 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
                                               ,len,(Uint8 *)mdcbufr);
                MdcDicomWriteItemDelItem(fi->ofp);
             }
-            MdcDicomWriteInfoSeqDelItem(fi->ofp);
+            MdcDicomWriteSeqDelItem(fi->ofp);
 
            MdcDicomWriteItemDelItem(fi->ofp);
-          MdcDicomWriteInfoSeqDelItem(fi->ofp);
+          MdcDicomWriteSeqDelItem(fi->ofp);
          MdcDicomWriteItemDelItem(fi->ofp);
       }
 
-      MdcDicomWriteInfoSeqDelItem(fi->ofp);
+      MdcDicomWriteSeqDelItem(fi->ofp);
 
     }
 
@@ -1966,12 +1976,12 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
     /* patient orientation code sequence */
     MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0410);
     /* sequence delimitation item */
-    MdcDicomWriteInfoSeqDelItem(fi->ofp);
+    MdcDicomWriteSeqDelItem(fi->ofp);
 
     /* patient gantry relationship code sequence */
     MdcDicomWriteInfoSeq(fi->ofp,0x0054,0x0414);
     /* sequence delimitation item */
-    MdcDicomWriteInfoSeqDelItem(fi->ofp);
+    MdcDicomWriteSeqDelItem(fi->ofp);
 
   }
 
@@ -1981,14 +1991,28 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 /* write Images */
 char *MdcDicomWriteG7FE0(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 {
-  Uint32 i, bytes, pixels, len, PAD_EVEN=0;
-  Uint8 *newbuff, *buff, c=0x00;
+  Uint32 i, bytes, pixels, length;
+  Uint8 *newbuff, *buff, c=0x00, PAD_EVEN=0;
   float slope, intercept;
 
   /* group 0x7FE0 - dump the images */
-  bytes = fi->number * fi->mwidth * fi->mheight * MdcType2Bytes(dicom->type);
+  if (dicom->ENCAPSULATED_UNCOMPRESSED == MDC_YES) {
+    /* one image per fragment (size > 4GB) */
+    bytes = fi->mwidth * fi->mheight * MdcType2Bytes(dicom->type);
+  }else{
+    /* all images fit in one fragment (size < 4GB) */
+    bytes = fi->number * fi->mwidth * fi->mheight * MdcType2Bytes(dicom->type);
+  }
+
   if (bytes%2) { PAD_EVEN=1; bytes+=1; }
-  mdc_dicom_write_element(fi->ofp,0x7fe0,0x0010,bytes,(Uint8 *)&dicom->type);
+
+  if (dicom->ENCAPSULATED_UNCOMPRESSED == MDC_YES) {
+    Uint8 vr_ob = BIT8_U;                                                   /* encapsulated: VR must be OB           */
+    mdc_dicom_write_element(fi->ofp,0x7fe0,0x0010,UNDEFINED_LENGTH,&vr_ob); /* pixel data element + vr + data length */
+    mdc_dicom_write_element(fi->ofp,0xfffe,0xe000,0,NULL);                  /* basic offset table with NO item value */
+  }else{
+    mdc_dicom_write_element(fi->ofp,0x7fe0,0x0010,bytes,(Uint8 *)&dicom->type);
+  }
 
   for (i=0; i<fi->number; i++) {
 
@@ -2012,30 +2036,50 @@ char *MdcDicomWriteG7FE0(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 
      pixels = fi->mwidth * fi->mheight;
      bytes = MdcType2Bytes(dicom->type);
+
+     if (dicom->ENCAPSULATED_UNCOMPRESSED == MDC_YES) {
+       length = pixels * bytes;
+       if (PAD_EVEN) length+=1;
+       mdc_dicom_write_element(fi->ofp,0xfffe,0xe000,length,NULL); /* item tag with item length */
+     }
+
      if (fwrite(buff,bytes,pixels,fi->ofp) != pixels)
        return("DICM Bad writing of image");
 
+     if ((dicom->ENCAPSULATED_UNCOMPRESSED == MDC_YES) && PAD_EVEN) {
+       /* one image per fragment, make even for each image */
+       if (fwrite(&c,1,1,fi->ofp) != 1) {
+         return("DICM Failed to pad encapsulated image fragment");
+       }
+     }
+
      MdcFree(buff);
   }
 
-  if (PAD_EVEN) {
+  if ((dicom->ENCAPSULATED_UNCOMPRESSED == MDC_NO) && PAD_EVEN) {
+    /* all images in one fragment, make even at the end */
     if (fwrite(&c,1,1,fi->ofp) != 1) {
-      return("DICM Failed to pad image");
+      return("DICM Failed to pad pixel data even");
     }
   }
 
+  if (dicom->ENCAPSULATED_UNCOMPRESSED == MDC_YES) {
+    /* finish encapsulated with sequence delim. tag */
+    MdcDicomWriteSeqDelItem(fi->ofp);
+  }
+
   if (MDC_QUANTIFY == MDC_YES || MDC_CALIBRATE == MDC_YES) {
     /* rewrite the true intercept value */
-    fseek(fi->ofp,(signed)MDC_REWRF_INTERCEPT,SEEK_SET);
+    fseeko(fi->ofp,MDC_REWRF_INTERCEPT,SEEK_SET);
     intercept = fi->image[0].rescaled_intercept;
-    sprintf(mdcbufr,"%+e",intercept); len = strlen(mdcbufr);
-    mdc_dicom_write_element(fi->ofp,0x0028,0x1052,len,(Uint8 *)mdcbufr);
+    sprintf(mdcbufr,"%+e",intercept); length = strlen(mdcbufr);
+    mdc_dicom_write_element(fi->ofp,0x0028,0x1052,length,(Uint8 *)mdcbufr);
 
     /* rewrite the true slope     value */
-    fseek(fi->ofp,(signed)MDC_REWRF_SLOPE,SEEK_SET);
+    fseeko(fi->ofp,MDC_REWRF_SLOPE,SEEK_SET);
     slope = fi->image[0].rescaled_slope;
-    sprintf(mdcbufr,"%+e",slope); len = strlen(mdcbufr);
-    mdc_dicom_write_element(fi->ofp,0x0028,0x1053,len,(Uint8 *)mdcbufr);
+    sprintf(mdcbufr,"%+e",slope); length = strlen(mdcbufr);
+    mdc_dicom_write_element(fi->ofp,0x0028,0x1053,length,(Uint8 *)mdcbufr);
   }
 
   return(NULL);
@@ -2045,6 +2089,7 @@ const char *MdcWriteDICM(FILEINFO *fi)
 {
   GATED_DATA tmpgd;
   MDC_DICOM_STUFF_T *dicom=&mdc_dicom_stuff;
+  Int64 bytes;
   const char *msg;
 
   if (MDC_DICOM_WRITE_IMPLICIT == MDC_YES) {
@@ -2107,6 +2152,26 @@ const char *MdcWriteDICM(FILEINFO *fi)
     MdcPrntWarn("DICM Only Int16 or Uint8 pixels supported");
   }
 
+  /* check for large file > 4GB OR forced encapsulated uncompressed */
+  if ( MDC_DICOM_WRITE_ENCAP_UNCOMP == MDC_YES ) {
+    dicom->ENCAPSULATED_UNCOMPRESSED = MDC_YES;
+  }else{
+    bytes = (Int64)fi->number * fi->mwidth * fi->mheight * MdcType2Bytes(dicom->type);
+    if ( bytes > ( (Int64)MdcTypeIntMax(BIT32_U) - 4 ) ) {
+      MdcPrntWarn("DICM Writing as Encapsulated Uncompressed Little Endian (size > 4GB)");
+      /* all images together do not fit in a single fragment       */
+      /* write as encapsulated uncompressed explicit little endian */
+      dicom->ENCAPSULATED_UNCOMPRESSED = MDC_YES;
+    }
+  }
+
+  if (dicom->ENCAPSULATED_UNCOMPRESSED == MDC_YES) {
+    /* now force explicit little endian */
+    MDC_DICOM_WRITE_IMPLICIT = MDC_NO;
+    MDC_DICOM_WRITE_NOMETA   = MDC_NO;
+    MDC_FILE_ENDIAN = MDC_LITTLE_ENDIAN;
+  }
+
   /* NM dynamic inappropriate for non-planar */
   if (dicom->modality == M_NM &&
       fi->planar == MDC_NO    &&
@@ -2147,7 +2212,7 @@ const char *MdcWriteDICM(FILEINFO *fi)
  * images *
  **********/
 
-static int mdc_dicom_read(FILEINFO *fi, IMAGE **image, int *number)
+static int mdc_dicom_read(FILEINFO *fi, IMAGE **image, Uint32 *number)
 {
   int err;
 
@@ -2155,7 +2220,7 @@ static int mdc_dicom_read(FILEINFO *fi, IMAGE **image, int *number)
 
   /* last argument: parametric(=1) (see more in vtdicom file transform.c)*/
   /* we need original values, preventing the rescaling to max/inverting  */
-  /* for doing the things ourselves (width/center or slope/intercept)    */
+  /* for doing the things ourselves (centre/width or slope/intercept)    */
 
   err = dicom_read(fi->ipath,image,number,1);
 
@@ -2290,35 +2355,67 @@ static void mdc_dicom_printinfo(const ELEMENT *e,const char *description)
     switch(e->vr)
     {
     case US :
+      if (e->value.US == NULL) {
+        MdcPrntWarn("Null pointer for US values");
+        return;
+      }
       MdcPrntScrn("%u ",e->value.US[i]);
       break;
 
     case SS :
+      if (e->value.SS == NULL) {
+        MdcPrntWarn("Null pointer for SS values");
+        return;
+      }
       MdcPrntScrn("%d ",e->value.SS[i]);
       break;
 
     case UL :
+      if (e->value.UL == NULL) {
+        MdcPrntWarn("Null pointer for UL values");
+        return;
+      }
       MdcPrntScrn("%u ",e->value.UL[i]);
       break;
 
     case SL :
+      if (e->value.SL == NULL) {
+        MdcPrntWarn("Null pointer for SL values");
+        return;
+      }
       MdcPrntScrn("%d ",e->value.SL[i]);
       break;
 
     case AT :
+      if (e->value.AT == NULL) {
+        MdcPrntWarn("Null pointer for AT values");
+        return;
+      }
       MdcPrntScrn("(%.4X,%.4X) ",e->value.AT[i].group,e->value.AT[i].element);
       break;
 
     case FL :
+      if (e->value.FL == NULL) {
+        MdcPrntWarn("Null pointer for FL values");
+        return;
+      }
       MdcPrntScrn("%f ",e->value.FL[i]);
       break;
 
     case FD :
+      if (e->value.FD == NULL) {
+        MdcPrntWarn("Null pointer for FD values");
+        return;
+      }
       MdcPrntScrn("%f ",e->value.FD[i]);
       break;
 
     case LT :
     case ST :
+      if (e->value.LT == NULL) {
+        MdcPrntWarn("Null pointer for LT values");
+        return;
+      }
       if (e->length > 128) {
         strcpy(mdcbufr,"...");
       }else{
@@ -2339,6 +2436,10 @@ static void mdc_dicom_printinfo(const ELEMENT *e,const char *description)
     case SH :
     case TM :
     case UI :
+      if (e->value.AE == NULL) {
+        MdcPrntWarn("Null pointer for AE values");
+        return;
+      }
       len = strlen(e->value.AE[i]);
       if (len > 128) {
         strcpy(mdcbufr,"...");
@@ -2374,7 +2475,7 @@ Uint8 *mdc_dicom_handle_vr(ELEMENT *e, Uint8 *tdata)
   switch (e->vr) {
     case ox:
         if ((e->group == 0x7fe0) && (e->element == 0x0010)) {
-          Int16 type; memcpy(&type,tdata,2);
+          Int8 type; memcpy(&type,tdata,1);
           switch (type) {
             case BIT8_U : e->vr = OB; return(NULL);
             case BIT16_S: e->vr = OW; return(NULL);
