@@ -28,7 +28,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -178,8 +178,8 @@ const char *MdcReadECAT6(FILEINFO *fi)
     MdcPrntScrn("Main Header (%d bytes)\n",MH_64_SIZE);
     MdcPrintLine('-',MDC_HALF_LENGTH);
 
-    MdcPrntScrn("Original Filename        : ");
-       MdcPrintStr(mh.original_file_name);
+    strncpy(mdcbufr,mh.original_file_name,20); mdcbufr[20]='\0';
+    MdcPrntScrn("Original Filename        : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Software Version         : %d\n",mh.sw_version);
     MdcPrntScrn("Data Type                : %d ",mh.data_type);
     if ((mh.data_type > -1) && (mh.data_type < 8))
@@ -192,17 +192,19 @@ const char *MdcReadECAT6(FILEINFO *fi)
       MdcPrntScrn("(= %s)\n",MdcEcatFileTypes[mh.file_type]);
     else
       MdcPrntScrn("(= Unknown)\n");
-    MdcPrntScrn("Node Id                  : "); MdcPrintStr(mh.node_id);
+    strncpy(mdcbufr,mh.node_id,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Node Id                  : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Scan Date - Day          : %d\n",mh.scan_start_day);
     MdcPrntScrn("          - Month        : %d\n",mh.scan_start_month);
     MdcPrntScrn("          - Year         : %d\n",mh.scan_start_year);
     MdcPrntScrn("          - Hour         : %d\n",mh.scan_start_hour);
     MdcPrntScrn("          - Minute       : %d\n",mh.scan_start_minute);
     MdcPrntScrn("          - Second       : %d\n",mh.scan_start_second);
-    MdcPrntScrn("Isotope Code             : "); MdcPrintStr(mh.isotope_code);
+    strncpy(mdcbufr,mh.isotope_code,8); mdcbufr[8]='\0';
+    MdcPrntScrn("Isotope Code             : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Isotope Halflife         : %f [sec]\n",mh.isotope_halflife);
-    MdcPrntScrn("Radiopharmaceutical      : ");
-      MdcPrintStr(mh.radiopharmaceutical);
+    strncpy(mdcbufr,mh.radiopharmaceutical,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Radiopharmaceutical      : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Gantry Tilt              : %f [degrees]\n",mh.gantry_tilt);
     MdcPrntScrn("Gantry Rotation          : %f [degrees]\n"
                                                           ,mh.gantry_rotation);
@@ -225,25 +227,29 @@ const char *MdcReadECAT6(FILEINFO *fi)
     else
       MdcPrntScrn("(= Unknown)\n");
     MdcPrntScrn("Compression Code         : %d\n",mh.compression_code);
-    MdcPrntScrn("Study Name               : "); MdcPrintStr(mh.study_name);
-    MdcPrntScrn("Patient Id               : "); MdcPrintStr(mh.patient_id);
-    MdcPrntScrn("Patient Name             : "); MdcPrintStr(mh.patient_name);
+    strncpy(mdcbufr,mh.study_name,12); mdcbufr[12]='\0';
+    MdcPrntScrn("Study Name               : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_id,16); mdcbufr[16]='\0';
+    MdcPrntScrn("Patient Id               : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_name,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Patient Name             : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Patient Sex              : "); MdcPrintChar(mh.patient_sex);
     MdcPrntScrn("\n");
-    MdcPrntScrn("Patient Age              : "); MdcPrintStr(mh.patient_age);
-    MdcPrntScrn("Patient Height           : ");
-       MdcPrintStr(mh.patient_height);
-    MdcPrntScrn("Patient Weight           : ");
-       MdcPrintStr(mh.patient_weight);
+    strncpy(mdcbufr,mh.patient_age,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Patient Age              : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_height,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Patient Height           : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.patient_weight,10); mdcbufr[10]='\0';
+    MdcPrntScrn("Patient Weight           : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Patient Dexterity        : ");
        MdcPrintChar(mh.patient_dexterity);
     MdcPrntScrn("\n");
-    MdcPrntScrn("Physician Name           : ");
-       MdcPrintStr(mh.physician_name);
-    MdcPrntScrn("Operator Name            : ");
-       MdcPrintStr(mh.operator_name);
-    MdcPrntScrn("Study Description        : ");
-       MdcPrintStr(mh.study_description);
+    strncpy(mdcbufr,mh.physician_name,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Physician Name           : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.operator_name,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Operator Name            : "); MdcPrintStr(mdcbufr);
+    strncpy(mdcbufr,mh.study_description,32); mdcbufr[32]='\0';
+    MdcPrntScrn("Study Description        : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Acquisition Type         : %d ",mh.acquisition_type);
     if ((mh.acquisition_type > -1) && (mh.acquisition_type <= 9))
       MdcPrntScrn("(= %s)\n",MdcEcatAcquisitionTypes[mh.acquisition_type]);
@@ -251,7 +257,8 @@ const char *MdcReadECAT6(FILEINFO *fi)
       MdcPrntScrn("(= Unknown)\n");
     MdcPrntScrn("Bed Type                 : %d\n",mh.bed_type);
     MdcPrntScrn("Septa Type               : %d\n",mh.septa_type);
-    MdcPrntScrn("Facility Name            : "); MdcPrintStr(mh.facility_name);
+    strncpy(mdcbufr,mh.facility_name,20); mdcbufr[20]='\0';
+    MdcPrntScrn("Facility Name            : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Number of Planes         : %d\n",mh.num_planes);
     MdcPrntScrn("Number of Frames         : %d\n",mh.num_frames);
     MdcPrntScrn("Number of Gates          : %d\n",mh.num_gates);
@@ -265,8 +272,8 @@ const char *MdcReadECAT6(FILEINFO *fi)
     MdcPrntScrn("Lower True Threshold     : %d [KeV]\n",mh.lwr_true_thres);
     MdcPrntScrn("Upper True Threshold     : %d [KeV]\n",mh.upr_true_thres);
     MdcPrntScrn("Collimator               : %6.0f\n",mh.collimator);
-    MdcPrntScrn("User Process Code        : ");
-       MdcPrintStr(mh.user_process_code);
+    strncpy(mdcbufr,mh.user_process_code,10); mdcbufr[10]='\0';
+    MdcPrntScrn("User Process Code        : "); MdcPrintStr(mdcbufr);
     MdcPrntScrn("Acquisition Mode         : %d\n",mh.acquisition_mode);
 
   }
@@ -642,7 +649,8 @@ const char *MdcReadECAT6(FILEINFO *fi)
                                              ,ish.filter_params[4]);
         MdcPrntScrn("Filter Params - Scatter Comp 2   : %f\n"
                                              ,ish.filter_params[5]);
-        MdcPrntScrn("Annotation : "); MdcPrintStr(ish.annotation);
+        strncpy(mdcbufr,ish.annotation,40); mdcbufr[40]='\0';
+        MdcPrntScrn("Annotation : "); MdcPrintStr(mdcbufr);
 
        }
 
@@ -887,7 +895,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
     fi->reconstructed = MDC_YES;
     if (ish.decay_corr_fctr > 1.0 ) fi->decay_corrected = MDC_YES;
 
-    MdcStringCopy(fi->recon_method,ish.annotation,strlen(ish.annotation));
+    MdcStringCopy(fi->recon_method,ish.annotation,strnlen(ish.annotation,40));
     if (strcmp(fi->recon_method,MDC_ECAT6_RECON_METHOD)  == 0 ) {
       strcpy(fi->recon_method,"Filtered Backprojection");
     }
@@ -960,16 +968,16 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
   /* memset(mh,0,MH_64_SIZE); */
   memset(mh,0,sizeof(Mdc_Main_header));
 
-  sprintf(mh->original_file_name,"%.19s",fi->ofname);
+  strncpy(mh->original_file_name,fi->ofname,20);
   mh->sw_version = 6;
   mh->system_type= 951;
   mh->file_type  = 2;
 
   mh->data_type = 2;     /* ECAT 6 only reads VAX Int16 */
 
-  sprintf(mh->isotope_code,"%.7s",fi->isotope_code);
+  strncpy(mh->isotope_code,fi->isotope_code,8);
   mh->isotope_halflife = fi->isotope_halflife;
-  sprintf(mh->radiopharmaceutical,"%.31s",fi->radiopharma);
+  strncpy(mh->radiopharmaceutical,fi->radiopharma,32);
   mh->calibration_units = fi->image[0].calibr_units;
   if (fi->pixdim[0] >= 3.) /* only valid for TRANSVERSE slices */
   mh->axial_fov = ((float)fi->dim[3] + 1.) * fi->pixdim[3] / 10.;
@@ -980,23 +988,25 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
   mh->scan_start_minute= fi->study_time_minute;
   mh->scan_start_second= fi->study_time_second;
   mh->plane_separation = fi->image[0].slice_spacing/10.; /* in cm */
-  sprintf(mh->study_name,"%.11s",fi->study_id);
+  strncpy(mh->study_name,fi->study_id,12);
   mh->gantry_tilt = fi->gantry_tilt;
-  sprintf(mh->patient_id,"%.15s",fi->patient_id);
+  strncpy(mh->patient_id,fi->patient_id,16);
   if (fi->patient_height == 0.) {
     mh->patient_height[0] = '\0';
   }else{
-    sprintf(mh->patient_height,"%.2f",fi->patient_height);
+    sprintf(mdcbufr,"%.2f",fi->patient_height);
+    strncpy(mh->patient_height,mdcbufr,10);
   }
   if (fi->patient_weight == 0.) {
     mh->patient_weight[0] = '\0';
   }else{
-    sprintf(mh->patient_weight,"%.2f",fi->patient_weight);
+    sprintf(mdcbufr,"%.2f",fi->patient_weight);
+    strncpy(mh->patient_weight,mdcbufr,10);
   }
-  sprintf(mh->patient_name,"%.31s",fi->patient_name);
+  strncpy(mh->patient_name,fi->patient_name,32);
   mh->patient_sex = fi->patient_sex[0];
-  sprintf(mh->operator_name,"%.31s",fi->operator_name);
-  sprintf(mh->study_description,"%.31s",fi->study_descr);
+  strncpy(mh->operator_name,fi->operator_name,32);
+  strncpy(mh->study_description,fi->study_descr,32);
   switch (fi->acquisition_type ) {
     case MDC_ACQUISITION_STATIC :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_STATIC_EMISSION;  break;
@@ -1010,8 +1020,8 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_UNKNOWN;
 
   }
-  sprintf(mh->facility_name,"%.19s",fi->institution);
-  sprintf(mh->user_process_code,"%.9s",MDC_PRGR);
+  strncpy(mh->facility_name,fi->institution,20);
+  strncpy(mh->user_process_code,MDC_PRGR,10);
 
   mh->num_planes = mh->num_frames = mh->num_gates = 1;
   mh->num_bed_pos = 1;
@@ -1136,9 +1146,9 @@ void MdcFillImageSubHeader(FILEINFO *fi,Mdc_Image_subheader *ish
   }
 
   if (strcmp(fi->recon_method,"Filtered Backprojection") == 0 ) {
-    sprintf(ish->annotation,"%.39s",MDC_ECAT6_RECON_METHOD);
+    strncpy(ish->annotation,MDC_ECAT6_RECON_METHOD,40);
   }else{
-    sprintf(ish->annotation,"%.39s",fi->recon_method);
+    strncpy(ish->annotation,fi->recon_method,40);
   }
 }
 
@@ -1298,8 +1308,8 @@ void MdcPrintEcatInfoDB(Mdc_Main_header *mh)
 
   Uint32 i, patient_strlen, study_strlen;
 
-  patient_strlen = strlen(mh->patient_name);
-  study_strlen   = strlen(mh->study_name);
+  patient_strlen = strnlen(mh->patient_name,32);
+  study_strlen   = strnlen(mh->study_name,12);
 
   /* remove # from strings, because it is used as field separator! */
   for (i=0; i<patient_strlen; i++) {
@@ -1312,7 +1322,7 @@ void MdcPrintEcatInfoDB(Mdc_Main_header *mh)
   if (study_strlen != 6) {
     MdcPrntScrn("%s",Unknown);
   }else{
-    MdcPrntScrn("%s",mh->study_name);
+    MdcPrntScrn("%.12s",mh->study_name);
   }
   MdcPrntScrn("# ");
 
@@ -1320,7 +1330,7 @@ void MdcPrintEcatInfoDB(Mdc_Main_header *mh)
   if (patient_strlen == 0) {
     MdcPrntScrn("%-35s",Unknown);
   }else{
-    MdcPrntScrn("%-35s",mh->patient_name);
+    MdcPrntScrn("%-35.32s",mh->patient_name);
   }
 
   MdcPrntScrn("#");
