@@ -64,7 +64,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -182,7 +182,7 @@ void MdcPrintImageLayout(FILEINFO *fi, Uint32 gen, Uint32 img, int repeat)
      else MdcPrntScrn("     !");
      MdcPrntScrn("\t(%ux%ux%u)",id->width,id->height,MdcType2Bytes(id->type));
      if (id->load_location != 0) {
-       MdcPrntScrn("\tOFFSET: %u",(Uint32)id->load_location);
+       MdcPrntScrn("\tOFFSET: %jd",(intmax_t)id->load_location);
      }
      MdcPrntScrn("\n");
 
@@ -233,13 +233,13 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
    case BIT64_S:
     {
       Int64 *val = (Int64 *) pvalue;
-      fprintf(fp,"%lld",val[0]);
+      fprintf(fp,"%jd",(intmax_t)val[0]);
     }
     break;
    case BIT64_U:
     {
       Uint64 *val = (Uint64 *) pvalue;
-      fprintf(fp,"%llu",val[0]);
+      fprintf(fp,"%ju",(uintmax_t)val[0]);
     }
     break;
    case FLT32:
@@ -283,6 +283,10 @@ void MdcKillSpaces(char string[]) /* kill first and last spaces */
 {
   int i=0, shift=0, length;
 
+  if (!string)  return; /* handle NULL  */
+
+  if (!*string) return; /* handle empty */
+
   length = strlen(string);
 
   if (length > 0) {
@@ -292,7 +296,7 @@ void MdcKillSpaces(char string[]) /* kill first and last spaces */
            i+=1; shift+=1;
          }else break;
     }
-    if (shift) for (i=0; i<=length; i++) string[i] = string[i+shift];
+    if (shift) for (i=0; (i+shift)<=length; i++) string[i] = string[i+shift];
 
     /* kill the last  spaces */
     length = strlen(string);
