@@ -50,7 +50,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -250,7 +250,7 @@ int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
   msg = NULL;
   if (MDC_INFO == MDC_NO) {
     if ((msg == NULL) && (MDC_CONTRAST_REMAP  == MDC_YES))
-      msg=MdcContrastRemap(fi);
+      msg=MdcContrastWindow(fi);
     if ((msg == NULL) && (MDC_MAKE_SQUARE     != MDC_NO))
       msg=MdcMakeSquare(fi,MDC_MAKE_SQUARE);
     if ((msg == NULL) && (MDC_FLIP_HORIZONTAL == MDC_YES))
@@ -277,7 +277,7 @@ int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
 
 }
 
-int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
+int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)(FILEINFO*))
 {
   const char *msg=NULL;
   Int8 INTERNAL_ENDIAN;
@@ -619,15 +619,15 @@ void MdcStringCopy(char *s1, char *s2, Uint32 length)
 }
 
 
-int MdcFileSize(FILE *fp)
+off_t MdcFileSize(FILE *fp)
 {
-  int size;
+  off_t size;
 
-  fseek(fp,0,SEEK_END);
+  fseeko(fp,(off_t)0,SEEK_END);
 
-  size=ftell(fp);
+  size=ftello(fp);
 
-  fseek(fp,0,SEEK_SET);
+  fseeko(fp,(off_t)0,SEEK_SET);
 
   return(size);
 
@@ -704,13 +704,14 @@ int MdcGetFrmt(FILEINFO *fi)
 #endif
     }
 
-    fseek(fi->ifp,0,SEEK_SET);
+    fseeko(fi->ifp,(off_t)0,SEEK_SET);
 
-    if ( format != MDC_FRMT_NONE ) break;
+    if ( format > MDC_FRMT_NONE ) break; /* a format was found */
 
   }
 
-  if (format == MDC_FRMT_NONE) {
+  if (format <= MDC_FRMT_NONE) {
+    /* none found; use fallback if set */
     if (MDC_FALLBACK_FRMT != MDC_FRMT_NONE) {
       MdcPrntWarn("Image format unknown - trying fallback format");
       format = MDC_FALLBACK_FRMT;
@@ -726,6 +727,8 @@ int MdcGetFrmt(FILEINFO *fi)
 
 Uint8 *MdcGetImgBuffer(Uint32 bytes)
 {
+  if (bytes == 0) return(NULL);
+  
   return((Uint8 *)calloc(1,bytes));
 }
 
