@@ -12,7 +12,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -49,14 +49,14 @@
 ****************************************************************************/
 
 int MdcOpenFile(FILEINFO *fi, const char *path);
-int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)());
-int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)());
+int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi));
+int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)(FILEINFO*));
 int MdcLoadFile(FILEINFO *fi);
 int MdcSaveFile(FILEINFO *fi, int format, int prefixnr);
 int MdcLoadPlane(FILEINFO *fi, Uint32 img);
 int MdcDecompressFile(const char *path);
 void MdcStringCopy(char *s1, char *s2, Uint32 length);
-int MdcFileSize(FILE *fp);
+off_t MdcFileSize(FILE *fp);
 int MdcFileExists(const char *fname);
 int MdcKeepFile(const char *fname);
 int MdcGetFrmt(FILEINFO *fi);
