@@ -19,7 +19,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -247,14 +247,15 @@ Format Analyze: [-spm -optspm]\n\
 #if (MDC_INCLUDE_DICM || MDC_INCLUDE_ACR)
   MdcPrntScrn("\n\
 Format DICOM:\n\
-\n a) general: [-cw=<center>:<width>]\n\
-             [-contrast] [-gap] [-implicit] [-nometa]\n\
-\n  -contrast, --enable-contrast  enable support for contrast changes\
+\n a) general: [-cw=<centre>:<width>]\n\
+             [-contrast] [-gap] [-implicit -nometa | -weu]\n\
+\n  -contrast, --enable-contrast  enable support for contrast window changes\
 \n  -gap, --spacing-true-gap      slice spacing is true gap or overlap");
   MdcPrntScrn("\
 \n  -implicit, --write-implicit   output file as implicit little endian\
 \n  -nometa, --write-without-meta output file without (part 10) meta header\
-\n  -cw                           force window center/width contrast");
+\n  -weu, --write-encap-uncomp    output file encapsulated uncompressed\
+\n  -cw                           force contrast window centre/width");
   MdcPrntScrn("\n\
 \n b) mosaic: [-mosaic | -fmosaic=<W>x<H>x<N> [-interl] [-mfixv]]\n\
 \n  -mosaic, --enable-mosaic      enable mosaic by \"detected\" stamps layout\
@@ -329,7 +330,7 @@ void MdcPrintShortInfo(void)
   }
     MdcPrntScrn(" Medical Image Conversion Utility\n");
     MdcPrntScrn("(X)MedCon %s\n",MdcGetLibShortVersion());
-    MdcPrntScrn("Copyright (C) 1997-2024 by Erik Nolf\n\n");
+    MdcPrntScrn("Copyright (C) 1997-2025 by Erik Nolf\n\n");
 
   if (XMDC_GUI == MDC_YES) {
     MdcPrntScrn("Try \'xmedcon --help\' for more information.\n\n");
@@ -677,6 +678,9 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
      }else if ( (strcasecmp(argv[a],"-nometa") == 0) ||
                 (strcasecmp(argv[a],"--write-without-meta") == 0) ) {
        MDC_DICOM_WRITE_NOMETA = MDC_YES; continue;
+     }else if ( (strcasecmp(argv[a],"-weu") == 0) ||
+                (strcasecmp(argv[a],"--write-encap-uncomp") == 0) ) {
+       MDC_DICOM_WRITE_ENCAP_UNCOMP = MDC_YES; continue;
 #endif
      }else if ( (strcasecmp(argv[a],"-fb-none") == 0) ||
                 (strcasecmp(argv[a],"--without-fallback") == 0) ) {
@@ -1147,10 +1151,18 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
     MdcPrntMesg("Mosaic fix voxel   is ON");
     if (MDC_TRUE_GAP == MDC_YES)
     MdcPrntMesg("True gap/overlap   is ON");
+
+    if (MDC_DICOM_WRITE_ENCAP_UNCOMP == MDC_YES) {
+
+    MdcPrntMesg("Dicom encap uncomp is ON");
+    }else{
+
     if (MDC_DICOM_WRITE_IMPLICIT == MDC_YES)
     MdcPrntMesg("Dicom implicit     is ON");
     if (MDC_DICOM_WRITE_NOMETA == MDC_YES)
     MdcPrntMesg("Dicom no meta      is ON");
+
+    }
     if (MDC_NORM_OVER_FRAMES == MDC_YES)
     MdcPrntMesg("Norm over frames   is ON");
     if (MDC_SKIP_PREVIEW == MDC_YES)
