@@ -12,7 +12,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -79,7 +79,7 @@ extern Int8 MDC_PADDING_MODE;
 extern Int8 MDC_ANLZ_SPM, MDC_ANLZ_OPTIONS;
 extern Int8 MDC_DICOM_MOSAIC_ENABLED, MDC_DICOM_MOSAIC_FORCED;
 extern Int8 MDC_DICOM_MOSAIC_DO_INTERL, MDC_DICOM_MOSAIC_FIX_VOXEL;
-extern Int8 MDC_DICOM_WRITE_IMPLICIT, MDC_DICOM_WRITE_NOMETA;
+extern Int8 MDC_DICOM_WRITE_IMPLICIT, MDC_DICOM_WRITE_NOMETA, MDC_DICOM_WRITE_ENCAP_UNCOMP;
 extern Int8 MDC_FORCE_RESCALE;
 extern Int8 MDC_FORCE_CONTRAST;
 extern Int8 MDC_HOST_ENDIAN, MDC_FILE_ENDIAN;
