@@ -20,7 +20,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -410,7 +410,7 @@ int MdcWriteHeadSpecs(FILEINFO *fi)
 
   Uint32 img;
 
-  fseek(fi->ofp,MDC_INW_HEAD_START_SIZE + MDC_INW_HEAD_GEN_SIZE,SEEK_SET);
+  fseeko(fi->ofp,MDC_INW_HEAD_START_SIZE + MDC_INW_HEAD_GEN_SIZE,SEEK_SET);
 
   for (img=0; img < fi->number; img++) {
 
