@@ -28,7 +28,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -105,7 +105,7 @@ Int32 mdc_mat_rblk( fptr, blkno, bufr, nblks)
   Uint8 *bufr;
 {
   int r;
-  fseek( fptr, (blkno-1)*MdcMatBLKSIZE, 0);
+  fseeko( fptr, (off_t)(blkno-1)*MdcMatBLKSIZE, 0);
   r = fread( bufr, 1, (unsigned)(nblks*MdcMatBLKSIZE), fptr);
   if (r != (nblks*MdcMatBLKSIZE)) return(-1);
 
@@ -911,7 +911,7 @@ Int32 mdc_mat_wblk( fptr, blkno, bufr, nblks)
 {
   Int32 err;
   /* seek to position in file */
-  err=fseek( fptr, (blkno-1)*MdcMatBLKSIZE, 0);
+  err=fseeko( fptr, (off_t)(blkno-1)*MdcMatBLKSIZE, 0);
   if (err) return(-1);
 
   /* write matrix data */
