@@ -24,7 +24,7 @@
  */
 
 /*
-   Copyright (C) 1997-2023 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -112,8 +112,6 @@ char *MdcUsePrevRawInput(FILEINFO *fi)
 
   /* prepare FILEINFO structure */
   for (i=0; i<fi->number; i++) {
-     if (MDC_PROGRESS)
-       MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
 
      id = &fi->image[i];
 
@@ -168,18 +166,18 @@ char *MdcAskRawInput(FILEINFO *fi)
   if (!MdcGetStructID(fi,number))
     return("RAW  Bad malloc IMG_DATA structs");
 
-  MdcPrntScrn("\tGeneral header offset to binary data [%u bytes]? "
-                ,prev->GENHDR);
+  MdcPrntScrn("\tGeneral header offset to binary data [%jd bytes]? "
+                ,(intmax_t)prev->GENHDR);
   if (MdcPutDefault(mdcbufr)) input->gen_offset = prev->GENHDR;
   else{
-      input->gen_offset = (Uint32)atol(mdcbufr);
+      input->gen_offset = (off_t)atoll(mdcbufr);
       prev->GENHDR = input->gen_offset;
   }
-  MdcPrntScrn("\tImage   header offset to binary data [%u bytes]? "
-                ,prev->IMGHDR);
+  MdcPrntScrn("\tImage   header offset to binary data [%jd bytes]? "
+                ,(intmax_t)prev->IMGHDR);
   if (MdcPutDefault(mdcbufr)) input->img_offset = prev->IMGHDR;
   else{
-      input->img_offset = (Uint32)atol(mdcbufr);
+      input->img_offset = (off_t)atoll(mdcbufr);
       prev->IMGHDR = input->img_offset;
   }
   MdcPrntScrn("\tImage   header repeated before each image ");
@@ -226,8 +224,6 @@ char *MdcAskRawInput(FILEINFO *fi)
   }
 
   for (i=0; i<fi->number; i++) {
-     if (MDC_PROGRESS)
-       MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
 
      id = &fi->image[i];
 
@@ -244,10 +240,10 @@ char *MdcAskRawInput(FILEINFO *fi)
 
      if (input->DIFF || (!input->DIFF && i==0)) {
 
-       MdcPrntScrn("\tAbsolute offset in bytes [%u]? ",prev->ABSHDR);
+       MdcPrntScrn("\tAbsolute offset in bytes [%jd]? ",(intmax_t)prev->ABSHDR);
        if (MdcPutDefault(mdcbufr)) id->load_location = prev->ABSHDR;
        else{
-         id->load_location = (size_t) atol(mdcbufr);
+         id->load_location = (off_t)atoll(mdcbufr);
          prev->ABSHDR = id->load_location;
        }
 
@@ -353,18 +349,20 @@ char *MdcReadRAW(FILEINFO *fi)
 
   if (MDC_VERBOSE) MdcPrntMesg("RAW  Reading <%s> ...",fi->ifname);
 
-  fseek(fi->ifp,(signed)input->gen_offset,SEEK_SET);
+  fseeko(fi->ifp,input->gen_offset,SEEK_SET);
 
   /* read the images */
   for (i = 0; i<fi->number; i++) {
 
+     if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
+
      id = &fi->image[i];
 
      if ( i==0  || input->REPEAT)
-       fseek(fi->ifp,(signed)input->img_offset,SEEK_CUR);
+       fseeko(fi->ifp,input->img_offset,SEEK_CUR);
 
      if (id->load_location != 0)
-       fseek(fi->ifp,id->load_location,SEEK_SET);
+       fseeko(fi->ifp,id->load_location,SEEK_SET);
 
      bytes = id->width * id->height * MdcType2Bytes(id->type);
      id->buf = MdcGetImgBuffer(bytes);
@@ -598,12 +596,12 @@ char *MdcReadPredef(const char *fname)
     return("Couldn't open raw predef input file");
   }else{
     MdcGetStrLine(mdcbufr,80,fp); prev->NRIMGS=(Uint32)atoi(mdcbufr);
-    MdcGetStrLine(mdcbufr,80,fp); prev->GENHDR=(Uint32)atoi(mdcbufr);
-    MdcGetStrLine(mdcbufr,80,fp); prev->IMGHDR=(Uint32)atoi(mdcbufr);
+    MdcGetStrLine(mdcbufr,80,fp); prev->GENHDR=(off_t)atoll(mdcbufr);
+    MdcGetStrLine(mdcbufr,80,fp); prev->IMGHDR=(off_t)atoll(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); if (mdcbufr[0] == 'y') prev->HDRREP = MDC_YES;
     MdcGetStrLine(mdcbufr,80,fp); if (mdcbufr[0] == 'y') prev->PSWAP = MDC_YES;
     MdcGetStrLine(mdcbufr,80,fp); if (mdcbufr[0] == 'y') { } /*no DIFF allowed*/
-    MdcGetStrLine(mdcbufr,80,fp); prev->ABSHDR=(Uint32)atoi(mdcbufr);
+    MdcGetStrLine(mdcbufr,80,fp); prev->ABSHDR=(off_t)atoll(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); prev->XDIM=(Uint32)atoi(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); prev->YDIM=(Uint32)atoi(mdcbufr);
     MdcGetStrLine(mdcbufr,80,fp); prev->PTYPE=(Int16)atoi(mdcbufr);
@@ -635,8 +633,8 @@ char *MdcWritePredef(const char *fname)
   }else{
     fprintf(fp,"%s - BEGIN #\n#\n",MDC_PREDEFSIG); /* MDC_PREDEFSIG - BEGIN */
     fprintf(fp,"# Total number of images?\n%u\n",prev->NRIMGS);
-    fprintf(fp,"# General header offset (bytes)?\n%u\n",prev->GENHDR);
-    fprintf(fp,"# Image   header offset (bytes)?\n%u\n",prev->IMGHDR);
+    fprintf(fp,"# General header offset (bytes)?\n%jd\n",(intmax_t)prev->GENHDR);
+    fprintf(fp,"# Image   header offset (bytes)?\n%jd\n",(intmax_t)prev->IMGHDR);
     fprintf(fp,"# Repeated image header?\n");
     if (prev->HDRREP == MDC_YES) {
       fprintf(fp,"yes\n");
@@ -650,7 +648,7 @@ char *MdcWritePredef(const char *fname)
       fprintf(fp,"no\n");
     }
     fprintf(fp,"# Identical images?\nyes\n");
-    fprintf(fp,"# Absolute offset in bytes?\n%u\n",prev->ABSHDR);
+    fprintf(fp,"# Absolute offset in bytes?\n%jd\n",(intmax_t)prev->ABSHDR);
     fprintf(fp,"# Image columns?\n%u\n",prev->XDIM);
     fprintf(fp,"# Image rows?\n%u\n",prev->YDIM);
     fprintf(fp,"# Pixel data type?\n%hu\n",prev->PTYPE);
