@@ -32,7 +32,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -976,7 +976,11 @@ void XMdcOptionsMedconAddTabFormats(GtkWidget *notebook)
   gtk_widget_show(button);
   sOptionsMedCon.DicmWriteImplicit = button;
 #if (MDC_INCLUDE_DICM || MDC_INCLUDE_ACR)
-  gtk_widget_set_sensitive(button,TRUE);
+  if (MDC_DICOM_WRITE_ENCAP_UNCOMP == MDC_YES) {
+    gtk_widget_set_sensitive(button,FALSE);
+  }else{
+    gtk_widget_set_sensitive(button,TRUE);
+  }
 #else
   gtk_widget_set_sensitive(button,FALSE);
 #endif
@@ -988,7 +992,11 @@ void XMdcOptionsMedconAddTabFormats(GtkWidget *notebook)
   gtk_widget_show(button);
   sOptionsMedCon.DicmWriteNoMeta = button;
 #if (MDC_INCLUDE_DICM || MDC_INCLUDE_ACR)
-  gtk_widget_set_sensitive(button,TRUE);
+  if (MDC_DICOM_WRITE_ENCAP_UNCOMP == MDC_YES) {
+    gtk_widget_set_sensitive(button,FALSE);
+  }else{
+    gtk_widget_set_sensitive(button,TRUE);
+  }
 #else
   gtk_widget_set_sensitive(button,FALSE);
 #endif
