@@ -24,7 +24,7 @@
  */
 
 /*
-   Copyright (C) 1997-2024 by Erik Nolf
+   Copyright (C) 1997-2025 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -270,21 +270,22 @@ void XMdcGetImageInfoCallbackApply(void)
 {
   IMG_DATA *id=NULL;
   const char *entry;
-  Uint32 i, width, height, imgnr, offset;
+  off_t offset;
+  Uint32 i, width, height, imgnr;
   Int16 type;
 
   imgnr = raw->ImgCounter - 1;
 
   MdcDebugPrint("image nr    = %u",imgnr);
   entry  = gtk_entry_get_text(GTK_ENTRY(raw->AbsOffset));
-  offset = (Uint32) atol(entry); prev->ABSHDR = offset;
-  MdcDebugPrint("abs offset  = %u",offset);
+  offset = (off_t) atoll(entry); prev->ABSHDR = offset;
+  MdcDebugPrint("abs offset  = %jd",(intmax_t)offset);
   entry = gtk_entry_get_text(GTK_ENTRY(raw->ImgWidth));
   width = (Uint32) atol(entry); prev->XDIM = width;
-  MdcDebugPrint("image width = %u",width);
+  MdcDebugPrint("image width = %lu",width);
   entry = gtk_entry_get_text(GTK_ENTRY(raw->ImgHeight));
   height= (Uint32) atol(entry); prev->YDIM = height;
-  MdcDebugPrint("image height= %u",height);
+  MdcDebugPrint("image height= %lu",height);
   type  = XMdcGetImageInfoPixelType(); prev->PTYPE = type;
 
   if (width == 0) {
@@ -300,7 +301,7 @@ void XMdcGetImageInfoCallbackApply(void)
 
   if (input->DIFF) {
     id = &my.fi->image[imgnr];
-    id->load_location = (size_t)offset;
+    id->load_location = offset;
     id->width = width;
     id->height= height;
     id->type  = type;
@@ -310,7 +311,7 @@ void XMdcGetImageInfoCallbackApply(void)
 
     for (i=0; i<my.fi->number; i++) {
        id = &my.fi->image[i];
-       id->load_location = (size_t)offset;
+       id->load_location = offset;
        id->width = width;
        id->height= height;
        id->type  = type;
@@ -388,8 +389,8 @@ void XMdcGetImageInfo(void)
   gtk_widget_show(label);
 
   entry = gtk_entry_new();
-  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
-  sprintf(xmdcstr,"%u",prev->ABSHDR);
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 19);
+  sprintf(xmdcstr,"%jd",(intmax_t)prev->ABSHDR);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
   gtk_grid_attach(GTK_GRID(grid),entry,1,0,1,1);
@@ -623,13 +624,13 @@ void XMdcGetHeaderInfoCallbackApply(void)
   }
   /* general header offset */
   entry = gtk_entry_get_text(GTK_ENTRY(raw->GenOffset));
-  input->gen_offset = (Uint32) atol(entry); prev->GENHDR=input->gen_offset;
-  MdcDebugPrint("general header offset = %u",input->gen_offset);
+  input->gen_offset = (off_t) atoll(entry); prev->GENHDR=input->gen_offset;
+  MdcDebugPrint("general header offset = %jd",(intmax_t)input->gen_offset);
 
   /* image   header offset */
   entry = gtk_entry_get_text(GTK_ENTRY(raw->ImgOffset));
-  input->img_offset = (Uint32) atol(entry); prev->IMGHDR=input->img_offset;
-  MdcDebugPrint("image  header offset = %u",input->gen_offset);
+  input->img_offset = (off_t) atoll(entry); prev->IMGHDR=input->img_offset;
+  MdcDebugPrint("image  header offset = %jd",(intmax_t)input->gen_offset);
 
   /* image   header repeated */
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(raw->IhdrRep))) {
@@ -715,7 +716,7 @@ void XMdcGetHeaderInfo(void)
   gtk_widget_show(label);
 
   entry = gtk_entry_new();
-  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 19);
   sprintf(xmdcstr,"%u",prev->NRIMGS);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
@@ -730,8 +731,8 @@ void XMdcGetHeaderInfo(void)
   gtk_widget_show(label);
 
   entry = gtk_entry_new();
-  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
-  sprintf(xmdcstr,"%u",prev->GENHDR);
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 19);
+  sprintf(xmdcstr,"%jd",(intmax_t)prev->GENHDR);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
   gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
   gtk_grid_attach(GTK_GRID(grid),entry,1,1,1,1);
@@ -745,8 +746,8 @@ void XMdcGetHeaderInfo(void)
   gtk_widget_show(label);
 
   entry = gtk_entry_new();
-  gtk_entry_set_max_length(GTK_ENTRY(entry), 10);
-  sprintf(xmdcstr,"%u",prev->IMGHDR);
+  gtk_entry_set_max_length(GTK_ENTRY(entry), 19);
+  sprintf(xmdcstr,"%jd",(intmax_t)prev->IMGHDR);
   gtk_entry_set_text(GTK_ENTRY(entry),xmdcstr);
   gtk_grid_attach(GTK_GRID(grid),entry,1,2,1,1);
   gtk_widget_show(entry);
